/*

Please let me know if you run into any problems while using this library/demo.



To use the demo:
Once the demo is running, click on the map to place a movement target.
To try using different movement procs, edit line 12 of demo.dm



2 simple steps to create a multitile atom:

First, set the atom's multitile var to one of the following values:

TWO_TALL	(two tiles tall, one tile wide)
TWO_WIDE	(two tiles wide, one tile tall)
FOUR_SQUARE	(four tiles arranged in a square)

Next, call the G_multitile() proc.
This is typically done as part of the atom's New() proc.

See the demo for an example of how to do this.



Additional atom configurations may be easily added.  To do so:
1) Open G-Move.dme
2) Add the following line: #define YOUR_DESIGNATION_HERE 4
	(For simplicity, use the same format as the existing definitions.)
3) In G-Move.dm, find the G_multitile() proc.
4) Add YOUR_DEFINITION_HERE to the switch.
5) Adjust xl and yl as necessary.  x[1] corresponds to y[1], etc.
6) Compile, and your new configuration is ready for use.



Implementation:

The following is a list of procs that are of likely interest to you,
along with an explanation of what they do and/or how they are used.


Can_Enter(turf/T,no_warp)
	Simply put, this is the equivalent of the returned portion of Enter()
	In this case, we're looking to see whether src can enter turf T.
	Multitile atoms are, of course, taken into account.
	Setting no_warp to 1 returns 0 if any of the turfs in question are warps.
	By default (no_warp = 0), warps are treated just like any other turf type.

G_get_dir(atom/A,atom/B)
G_get_dist(atom/A,atom/B)
G_get_true_dist(atom/A,atom/B)

	These procs find the direction or shortest distance between two atoms.
	Either, both, or neither of the two atoms may be multitile.
	G_get_dist() behaves just like get_dist()
	G_get_true_dist() returns the hypotenuse of the triangle formed by the
		two closest component tiles of A and B

G_get_step(Dir)
G_step(Dir)
G_walk(Dir,Lag=1)

	Notice that all movement procs in this library take the
	Ref argument and make it the proc's src.
	Thus walk(Ref,Dir,Lag=0) becomes src.walk(Dir,Lag=0)

	These three procs are no different from their default
	counterparts.  They were recreated for the library for
	the sake of continuity.

G_get_step_to(Trg,Min=0,Limit=10)
G_step_to(Trg,Min=0,Limit=10)
G_walk_to(Trg,Min=0,Lag=1,Limit=10)

	walk_to(Ref,Trg,Min=0,Lag=0) for comparison:

	Aside from multitile support, there are a few important changes
	in the way G_step_to() works.

	First, regardless of how far apart Trg and src are located,
	src will still plot a course in the direction of Trg.

	Second is the added Limit argument.
	As paths are generated, the number of steps required to
	reach any point in a potential path is stored.  If this
	number exceeds Limit, then the best possible path is
	chosen.  Put another way, G_step_to() returns the first step
	on the path that is the best 10-step path, if Limit is 10.
	Limit behaves this way for all procs that use it.

	Third, G_step_to can plot a simple course through warps to reach
	Trg.  So even if Trg and src are on different z levels, or even
	far apart on the same z-level, the movement system can in many cases
	plot a course between Trg and src.

G_get_step_away(Trg,Max=5,Min=0,Limit=10)
G_step_away(Trg,Max=5,Min=0,Limit=10)
G_walk_away(Trg,Max=5,Min=0,Lag=1,Limit=10)

	walk_away(Ref,Trg,Max=5,Lag=0) for comparison:

	The new Min value represents the closest that src
	will pass by Trg while trying to step/walk away.
	Thus instead of stupidly walking into a corner
	while trying to walk_away from Trg, src might instead
	walk past Trg and flee in the other direction.

G_get_step_towards(Trg,Min=0)
G_step_towards(Trg,Min=0)
G_walk_towards(Trg,Min=0,Lag=1)

	One major change:
	Instead of being hung up on every single obstacle as with step_toward(),
	simple obstructions will be side-stepped.

G_get_step_rand()
G_step_rand()
G_walk_rand(Lag=1)

	This is similar to step_rand(), but with added multitile support.
	Two important details:
	Steps are only taken in directions in which the atom can move.
		i.e. - A dense atom will never try to walk into a wall.
	Warps are avoided.


G_get_stumble_step_to(Trg,Min=0,Prob=100)
G_get_stumble_step_away(Trg,Max=100,Prob=100)
G_stumble_step_to(Trg,Min=0,Prob=100)
G_stumble_step_away(Trg,Max=100,Prob=100)
G_stumble_walk_to(Trg,Min=0,Lag=1,Prob=100)
G_stumble_walk_away(Trg,Max=100,Lag=1,Prob=100)

	G_stumble_step_to/away() can best be described as a sort of drunken swagger.

	In the case of G_stumble_step_to(), src takes a random step that places src either
	closer to or no-further-away from Trg.  The opposite is true of G_stumble_step_away().

	Prob-100 is the probability of src taking a step in a completely random direction.
	Prob=100 is thus a 100% stumble success rate.

*/